@@ -12,3 +12,8 @@
 #undef HAVE_SDLLIB
 #undef HAVE_LIBDC
 #undef HAVE_LIBRAW
+#undef HAVE_GDK_PIXBUF
+#undef MMX_SUPPORT
+#undef SSE_SUPPORT
+#undef SSE2_SUPPORT
+#undef HAVE_XV
