@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 Damien Douxchamps  <douxchamps@ieee.org>
+ * Copyright (C) 2000-2003 Damien Douxchamps  <ddouxchamps@users.sf.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,6 +20,25 @@
 #ifndef __BUILDFRAMES_H__
 #define __BUILDFRAMES_H__
 
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif 
+
+#include <gnome.h>
+#include <libdc1394/dc1394_control.h>
+#include "support.h"
+#include "preferences.h"
+#include "definitions.h"
+#include "build_menus.h"
+#include "tools.h"
+#include "thread_save.h"
+#include "thread_ftp.h"
+#include "thread_iso.h"
+#include "callbacks.h"
+
+void
+BuildPrefsGeneralFrame(void);
+
 void
 BuildCameraFrame(void);
 
@@ -44,6 +63,9 @@ BuildCaptureFrame(void);
 void
 BuildIsoFrame(void);
 
+void
+BuildGlobalIsoFrame(void);
+
 void
 BuildFormat7ModeFrame(void);
 
@@ -60,12 +82,17 @@ void
 BuildPrefsFtpFrame(void);
 
 void
-BuildPrefsRealFrame(void);
+BuildPrefsDisplayFrame(void);
 
 void
-BuildPrefsDisplayFrame(void);
+BuildPrefsV4lFrame(void);
 
 void
 BuildPrefsReceiveFrame(void);
 
+void
+BuildOptionFrame(void);
+
+void
+BuildBandwidthFrame(void);
 #endif
