@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 Damien Douxchamps  <douxchamps@ieee.org>
+ * Copyright (C) 2000-2003 Damien Douxchamps  <ddouxchamps@users.sf.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,6 +18,14 @@
 
 #ifndef __BUILDMENUS_H__
 #define __BUILDMENUS_H__
+
+#include <gnome.h>
+#include <libdc1394/dc1394_control.h>
+#include "preferences.h"
+#include "definitions.h"
+#include "tools.h"
+#include "support.h"
+
 void
 BuildTriggerModeMenu(void);
 
@@ -36,4 +44,16 @@ BuildFormat7ModeMenu(void);
 void
 BuildFpsMenu(void);
 
+void
+BuildFormatMenu(void);
+
+void
+BuildBayerMenu(void);
+
+void
+BuildBayerPatternMenu(void);
+
+void
+BuildStereoMenu(void);
+
 #endif
