@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 Damien Douxchamps  <douxchamps@ieee.org>
+ * Copyright (C) 2000-2003 Damien Douxchamps  <ddouxchamps@users.sf.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,11 +19,22 @@
 #ifndef __BUILDRANGES_H__
 #define __BUILDRANGES_H__
 
+#include <gnome.h>
+#include <libdc1394/dc1394_control.h>
+#include "definitions.h"
+#include "support.h"
+#include "callbacks.h"
+
 void
-BuildRange(GtkWidget* current_window, int feature);
+BuildRange(int feature);
+
+void
+BuildEmptyRange(int feature);
 
 void 
 BuildFormat7Ranges(void);
 
+void
+BuildFormat7BppRange(void);
 
 #endif
