@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 Damien Douxchamps  <douxchamps@ieee.org>
+ * Copyright (C) 2000-2003 Damien Douxchamps  <ddouxchamps@users.sf.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,10 @@
 #ifndef __BUILDWINDOWS_H__
 #define __BUILDWINDOWS_H__
 
+#include <gnome.h>
+#include "definitions.h"
+#include "build_frames.h"
+
 void
 BuildFormat7Window(void);
 
@@ -26,22 +30,10 @@ void
 BuildPreferencesWindow(void);
 
 void
-BuildColorWindow(void);
+BuildMainWindow(void);
 
 void
-BuildPositionWindow(void);
-
-void
-BuildApertureWindow(void);
-
-void
-BuildCommanderWindow(void);
-
-void
-BuildCaptureWindow(void);
-
-void
-BuildTemperatureWindow(void);
+BuildFeatureWindow(void);
 
 void
 BuildStatusWindow(void);
@@ -49,4 +41,10 @@ BuildStatusWindow(void);
 void
 BuildAllWindows(void);
 
+void
+BuildHelpWindow(void);
+
+void
+BuildAbsoluteSettingsWindow(void);
+
 #endif
