@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 Damien Douxchamps  <douxchamps@ieee.org>
+ * Copyright (C) 2000-2003 Damien Douxchamps  <ddouxchamps@users.sf.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,45 +19,50 @@
 #ifndef __THREAD_DISPLAY_H__
 #define __THREAD_DISPLAY_H__
 
-#ifdef HAVE_X11_EXTENSIONS_XVLIB_H
-#include <X11/Xlib.h>
-#include <sys/ipc.h>
-#include <sys/shm.h>
-#include <X11/extensions/XShm.h>
-#include <X11/extensions/Xvlib.h>
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
 #endif
 
 #ifdef HAVE_SDLLIB
 #include "SDL.h"
+#include "SDLEvent.h"
 #endif
 
-#include <gdk/gdk.h>
-#include <gtk/gtk.h>
-#include "thread_base.h" 
+#include <math.h>
+#include "support.h"
+#include "definitions.h"
+#include "thread_base.h"
+#include "watch_thread.h"
+#include "preferences.h"
+
+typedef enum
+{
+  DISPLAY_REDRAW_OFF=0,
+  DISPLAY_REDRAW_ON
+} display_redraw_t;
 
 typedef struct
 {
   long int                period;
-  pthread_mutex_t         mutex_cancel_display;
-  int                     cancel_display_req;
+  pthread_mutex_t         mutex_cancel;
+  int                     cancel_req;
+
+  struct tms redraw_tms_buf;
+  clock_t redraw_prev_time;
+  clock_t redraw_current_time;
 
 #ifdef HAVE_SDLLIB
 
-  long unsigned int SDL_flags;
-  int SDL_bpp;
+  // general SDL stuff
+  long unsigned int sdlflags;
+  int sdlbpp;
+  SDL_Surface *sdlvideo;   // video surface
+  SDL_Overlay *sdloverlay; // video overlay surface
+  SDL_Rect sdlvideorect;   // video rectangle for overlay surface
 
-  SDL_Surface *SDL_video;
-  // video surface
-
-  SDL_Overlay *SDL_overlay;
-  // video overlay surface
-
-  SDL_Rect SDL_videoRect;
-  // video rectangle for overlay surface blitting to video surface
- 
+  // events
   pthread_mutex_t         mutex_cancel_event;
   int                     cancel_event_req;
-
   pthread_mutex_t         mutex_event;
   pthread_t               event_thread;
 
@@ -66,7 +71,7 @@ typedef struct
 } displaythread_info_t;
 
 gint
-DisplayStartThread(void);
+DisplayStartThread(camera_t* cam);
 
 void*
 DisplayCleanupThread(void* arg);
@@ -75,17 +80,28 @@ void*
 DisplayThread(void* arg);
 
 gint
-DisplayStopThread(unsigned int camera);
-
-#ifdef HAVE_SDLLIB
-int
-sdlInit(chain_t *display_service);
-
-int
-GetSDLVideoMode(int mode);
+DisplayStopThread(camera_t* cam);
 
 void
-convert_to_yuv_for_SDL(unsigned char *src, unsigned char *dest, int mode, int width, int height);
+ConditionalTimeoutRedraw(chain_t* service);
+
+#ifdef HAVE_SDLLIB
+
+int
+SDLInit(chain_t *display_service);
+
+void
+convert_to_yuv_for_SDL(buffer_t *buffer, SDL_Overlay *sdloverlay);
+
+void
+SDLDisplayArea(chain_t *display_service);
+
+void
+SDLQuit(chain_t *display_service);
+
+void
+DisplayThreadCheckParams(chain_t *display_service);
+
 #endif
 
 #endif
