@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 Damien Douxchamps  <douxchamps@ieee.org>
+ * Copyright (C) 2000-2003 Damien Douxchamps  <ddouxchamps@users.sf.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,31 +16,47 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include <gnome.h>
-
 #ifndef __THREAD_FTP_H__
 #define __THREAD_FTP_H__
 
+
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #ifdef HAVE_FTPLIB
 #include <ftplib.h>
 #endif
 
-#include <pthread.h> 
+#include <pthread.h>
+#include <sys/times.h>
+#include <gnome.h>
+#include <math.h>
+#include "support.h"
 #include "definitions.h"
+#include "thread_base.h"
+#include "tools.h"
+
 
 typedef enum
 {
-  FTP_SCRATCH_SEQUENTIAL,
+  FTP_SCRATCH_SEQUENTIAL=0,
   FTP_SCRATCH_OVERWRITE
 } ftp_scratch_t;
  
+typedef enum
+{
+  FTP_TAG_DATE=0,
+  FTP_TAG_NUMBER
+} ftp_tag_t;
+ 
 typedef struct
 { 
   /* Define thread variables here.
      This data will only de available to the thread.*/
 
-  pthread_mutex_t    mutex_cancel_ftp;
-  int                cancel_ftp_req;
+  pthread_mutex_t    mutex_cancel;
+  int                cancel_req;
   char               filename[STRING_SIZE];
   char               filename_ext[STRING_SIZE];
   char               address[STRING_SIZE];
@@ -50,8 +66,9 @@ typedef struct
   long int           period;
   long int           counter;
   long int           imlib_buffer_size;
-  unsigned char*     ftp_buffer;
-  int                ftp_scratch;
+  unsigned char*     buffer;
+  int                scratch;
+  int                datenum;
 #ifdef HAVE_FTPLIB
   netbuf             *ftp_handle;
 #endif
@@ -59,7 +76,7 @@ typedef struct
 } ftpthread_info_t;
 
 gint
-FtpStartThread(void);
+FtpStartThread(camera_t* cam);
 
 void*
 FtpCleanupThread(void* arg);
@@ -68,7 +85,10 @@ void*
 FtpThread(void* arg);
 
 gint
-FtpStopThread(void);
+FtpStopThread(camera_t* cam);
+
+void
+FtpThreadCheckParams(chain_t *ftp_service);
 
 #ifdef HAVE_FTPLIB
 
