@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 Damien Douxchamps  <douxchamps@ieee.org>
+ * Copyright (C) 2000-2003 Damien Douxchamps  <ddouxchamps@users.sf.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,31 +16,55 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include <gnome.h>
-
 #ifndef __THREAD_ISO_H__
 #define __THREAD_ISO_H__
 
-#define DMA_BUFFERS 4
+#ifdef HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
+#include <gnome.h>
+#include <pthread.h>
+#include <sys/times.h>
+#include <sys/timeb.h>
+#include <libdc1394/dc1394_control.h>
+#include <math.h>
+#include "support.h"
+#include "thread_base.h"
+#include "topology.h"
+#include "definitions.h"
+#include "tools.h" 
 
 typedef enum
 {
-  //RECEIVE_METHOD_AUTO=0,
   RECEIVE_METHOD_RAW1394=0, 
   RECEIVE_METHOD_VIDEO1394
 } receive_method_t;
 
-
 typedef struct
 { 
   raw1394handle_t         handle;
   receive_method_t        receive_method;
   dc1394_cameracapture    capture;
+  int video1394_dropframes;
+  char video1394_device[STRING_SIZE];
+
+  unsigned char *temp;
+  long long unsigned int temp_size;
+  int temp_allocated;
+
+  int orig_sizex;
+  int orig_sizey;
+  int cond16bit;
+
+  int dma_buffer_size;
+
+  struct timeval rawtime;
 
 } isothread_info_t;
 
 gint
-IsoStartThread(void);
+IsoStartThread(camera_t* cam);
 
 void*
 IsoCleanupThread(void* arg);
@@ -49,6 +73,20 @@ void*
 IsoThread(void* arg);
 
 gint
-IsoStopThread(void);
+IsoStopThread(camera_t* camera);
+
+void
+IsoThreadCheckParams(chain_t *iso_service);
+
+void
+AllocTempBuffer(long long unsigned int requested_size, isothread_info_t* info);
+
+void
+AllocImageBuffer(chain_t* iso_service);
+
+void
+SetColorMode(buffer_t *buffer);
 
 #endif
+
+
