@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 Damien Douxchamps  <douxchamps@ieee.org>
+ * Copyright (C) 2000-2003 Damien Douxchamps  <ddouxchamps@users.sf.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -16,40 +16,63 @@
  * Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
-#include <gnome.h>
-
 #ifndef __THREAD_SAVE_H__
 #define __THREAD_SAVE_H__
 
-
 #include <pthread.h>
+#include <sys/times.h>
+#include <math.h>
+#include "support.h"
+#include "thread_base.h"
+#include "preferences.h"
 #include "definitions.h"
+#include "tools.h"
 
 typedef enum
 {
-  SAVE_SCRATCH_SEQUENTIAL,
-  SAVE_SCRATCH_OVERWRITE
+  SAVE_SCRATCH_SEQUENTIAL=0,
+  SAVE_SCRATCH_OVERWRITE,
+  SAVE_SCRATCH_VIDEO
 } save_scratch_t;
 
+typedef enum
+{
+  SAVE_TAG_DATE=0,
+  SAVE_TAG_NUMBER
+} save_tag_t;
+ 
+
+typedef enum
+{
+  SAVE_CONVERT_ON=0,
+  SAVE_CONVERT_OFF
+} save_convert_t;
+
 
 typedef struct
 { 
   /* Define thread variables here.
      This data will only de available to the thread.*/
 
-  pthread_mutex_t    mutex_cancel_save;
-  int                cancel_save_req;
+  pthread_mutex_t    mutex_cancel;
+  int                cancel_req;
   char               filename[STRING_SIZE];
   char               filename_ext[STRING_SIZE];
   long int           counter;
-  unsigned char*     save_buffer;
-  int                save_scratch;
+  unsigned char*     buffer;
+  int                scratch;
+  int                datenum;
   long int           period;
+  int                rawdump;
+  unsigned char*     bigbuffer;
+  unsigned long int  bigbuffer_position;
+  unsigned long int  ram_buffer_size;
+  int                use_ram_buffer;
 
 } savethread_info_t;
 
 gint
-SaveStartThread(void);
+SaveStartThread(camera_t* cam);
 
 void*
 SaveCleanupThread(void* arg);
@@ -58,6 +81,9 @@ void*
 SaveThread(void* arg);
 
 gint
-SaveStopThread(void);
+SaveStopThread(camera_t* cam);
+
+void
+SaveThreadCheckParams(chain_t *save_service);
 
 #endif
