@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 Damien Douxchamps  <douxchamps@ieee.org>
+ * Copyright (C) 2000-2004 Damien Douxchamps  <ddouxchamps@users.sf.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,8 +19,21 @@
 #ifndef __UPDATEFRAMES_H__
 #define __UPDATEFRAMES_H__
 
+#include <gnome.h>
+#include <libdc1394/dc1394_control.h>
+#include "support.h"
+#include "definitions.h"
+#include "raw1394support.h"
+#include "tools.h"
+#include "build_menus.h"
+#include "thread_base.h"
+#include "thread_save.h"
+#include "thread_ftp.h"
+#include "thread_iso.h"
+#include "build_ranges.h"
+
 void
-UpdatePrefsUpdateFrame(void);
+UpdatePrefsGeneralFrame(void);
 
 void
 UpdatePrefsDisplayFrame(void);
@@ -28,9 +41,6 @@ UpdatePrefsDisplayFrame(void);
 void
 UpdatePrefsReceiveFrame(void);
 
-void
-UpdatePrefsRealFrame(void); 
-
 void
 UpdateCameraFrame(void);
 
@@ -65,6 +75,24 @@ void
 UpdatePrefsFtpFrame(void);
 
 void
-UpdateServicesFrame(void);
+UpdatePrefsV4lFrame(void);
+
+void
+UpdateCursorFrame(void);
+
+void
+UpdateOptionFrame(void);
+
+void
+UpdateServiceFrame(void);
+
+void
+UpdateFormat7InfoFrame(void);
+
+void
+UpdateBandwidthFrame(void);
+
+void
+UpdateServiceTree(void);
 
 #endif
