@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 Damien Douxchamps  <douxchamps@ieee.org>
+ * Copyright (C) 2000-2003 Damien Douxchamps  <ddouxchamps@users.sf.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,11 @@
 #ifndef __UPDATEMENUS_H__
 #define __UPDATEMENUS_H__
 
+#include <gnome.h>
+#include <libdc1394/dc1394_control.h>
+#include "support.h"
+#include "tools.h"
+
 void
 UpdateFormatMenu(void);
 
