@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2000-2002 Damien Douxchamps  <douxchamps@ieee.org>
+ * Copyright (C) 2000-2003 Damien Douxchamps  <ddouxchamps@users.sf.net>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,6 +19,12 @@
 #ifndef __UPDATEWINDOWS_H__
 #define __UPDATEWINDOWS_H__
 
+#include <libdc1394/dc1394_control.h> 
+#include "update_ranges.h"
+#include "build_menus.h"
+#include "update_frames.h"
+#include "update_menus.h"
+
 void 
 UpdateFormat7Window(void);
 
@@ -29,23 +35,11 @@ void
 UpdatePreferencesWindow(void);
 
 void
-UpdatePositionWindow(void);
-
-void
-UpdateColorWindow(void);
-
-void
-UpdateApertureWindow(void);
-
-void
-UpdateTemperatureWindow(void);
+UpdateFeatureWindow(void);
 
 void
 UpdateStatusWindow(void);
 
-void
-UpdateCaptureWindow(void);
-
 void
 UpdateAllWindows(void);
 
